(document:surround "/std/frame")
(document:insert "/std/functions")

;;; language stuff

(define (current-language)
  (and-let* ((l (langlist value)))
    (string-cut l #\:)))

(define (label+icon x)
  (cons (woo-get-option x 'label)
        (woo-get-option x 'icon)))

(define (change-translations)
  (define-operation set-lang)
  (set-lang (fluid-ref generic-session) (current-language))

  ;;wizardface specific hacks
  (and-let* ((wizard-id (global 'frame:wizard))
	     (_ (make-translator "alterator-wizard" (session-language))))
    (wizard-id steps-clear)
    (wizard-id steps (map label+icon (woo-list "/step-list")))
    (wizard-id current-step 0)
    (wizard-id action-text 'help (_ "Help"))
    (wizard-id action-text 'forward (_ "Next")))

  ;;common hacks
  (let ((_ (make-translator "alterator-sysconfig" (session-language))))
    (label1 text (_ "Select your language:"))
    (label2 text (_ "Please select keyboard switch type:"))))

(define (default-language)
  (define-operation get-lang)
  (string-join (get-lang (fluid-ref generic-session)) ":"))

(define (update-lang)
  (change-translations)
  (keyboard-type enumref "/sysconfig-base/kbd")
  (and (positive? (keyboard-type count)) (default-keyboard)))

;;; keyboard stuff

(define (default-keyboard)
  (keyboard-type value (woo-get-option (woo-read-first "/sysconfig-base/kbd") 'layout))
  (or (positive? (keyboard-type current))
      (keyboard-type current 0)))

(define (write-sysconfig)
  (catch/message
    (lambda()
      (let ((lang (current-language))
	    (kbd (keyboard-type value)))
	(woo-write "/sysconfig-base/language" 'lang lang)
	(woo-write "/sysconfig-base/kbd" 'layout kbd)
	(simple-notify document:root 'action "language" 'value lang)
	#t))))

;;;;;;;;;;;;

(gridbox
  columns "100"
  margin 50

  (document:id label1 (label text "Select your language:"))

  (document:id langlist (listbox (when selected (update-lang))))

  (label)

  (document:id label2 (label text "Please select keyboard switch type:"))

  (document:id keyboard-type (listbox)))

(frame:on-next (thunk (or (write-sysconfig) 'cancel)))

(document:root
  (when loaded
    (catch/message
      (lambda()
	(langlist enumref "/sysconfig-base/language"
		  value (default-language)
		  selected)))))
